@@ -12,7 +12,7 @@ pub mod wzium_lib{
     pub fn wzium(print_certificate: bool)-> String{
         if print_certificate{
             println!("===============================");
-            println!("This is official wzium library!");
+            println!("This is wzium library!");
             println!("===============================");
         }
         String::from("WZIUM")
